#include <esp_now.h>
#include <WiFi.h>

#define RightFrontFWD   32
#define RightFrontBWD   33
#define RightBackFWD    25
#define RightBackBWD    26

#define LeftFrontFWD    18
#define LeftFrontBWD    19
#define LeftBackFWD     23
#define LeftBackBWD     27

// Structure example to receive data
// Must match the sender structure
typedef struct struct_message {
  int rightJoyXvalue;
  int rightJoyYvalue;
  int rightJoySWvalue;
  int rightButtonAvalue;
  int rightButtonBvalue;
  int leftJoyXvalue;
  int leftJoyYvalue;
  int leftJoySWvalue;
  int leftButtonAvalue;
  int leftButtonBvalue;
} struct_message;

int moveForward;
int moveBackward;
int rotateLeft;
int rotateRight;
int moveSidewaysRight;
int moveSidewaysLeft;

// Create a struct_message called myData
struct_message readingData;

// callback function that will be executed when data is received
void OnDataRecv(const uint8_t * mac, const uint8_t *incomingData, int len) {
  memcpy(&readingData, incomingData, sizeof(readingData));
  Serial.print("Bytes received: ");
  Serial.println(len);
  
  moveForward = readingData.rightJoyXvalue;
  Serial.print("Right Joystick X Value: ");
  Serial.println(readingData.rightJoyXvalue);
  Serial.println();
  digitalWrite(RightFrontFWD, moveForward);
  digitalWrite(RightBackFWD, moveForward);
  digitalWrite(LeftFrontFWD, moveForward);
  digitalWrite(LeftBackFWD, moveForward);

  moveBackward = readingData.leftJoyXvalue;
  Serial.print("Left Joystick X Value: ");
  Serial.println(readingData.leftJoyXvalue);
  Serial.println();
  digitalWrite(RightFrontBWD, moveBackward);
  digitalWrite(RightBackBWD, moveBackward);
  digitalWrite(LeftFrontBWD, moveBackward);
  digitalWrite(LeftBackBWD, moveBackward);

  rotateLeft = readingData.leftJoyYvalue;
  Serial.print("Left Joystick Y Value: ");
  Serial.println(readingData.leftJoyYvalue);
  Serial.println();
  digitalWrite(RightFrontFWD, rotateLeft);
  digitalWrite(RightBackFWD, rotateLeft);
  digitalWrite(LeftFrontBWD, rotateLeft);
  digitalWrite(LeftBackBWD, rotateLeft);
}
 
void setup() {
  // Initialize Serial Monitor
  Serial.begin(115200);

  pinMode(RightFrontFWD, OUTPUT);
  pinMode(RightBackFWD, OUTPUT);
  pinMode(RightBackBWD, OUTPUT);
  pinMode(LeftFrontFWD, OUTPUT);
  pinMode(LeftFrontBWD, OUTPUT);
  pinMode(LeftBackFWD, OUTPUT);
  pinMode(LeftBackBWD, OUTPUT);
  
  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);

  // Init ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  
  // Once ESPNow is successfully Init, we will register for recv CB to
  // get recv packer info
  esp_now_register_recv_cb(OnDataRecv);
}
 
void loop() {

}
